// list module mutations
export const ADD_CONTACT = 'ADD_CONTACT'
export const DELETE_CONTACT = 'DELETE_CONTACT'
export const SET_CONTACTS = 'SET_CONTACTS'
export const UPDATE_CONTACT = 'UPDATE_CONTACT'

// detail module mutations
export const SET_CONTACT = 'SET_CONTACT'

// categories module mutations
export const ADD_CATEGORY = 'ADD_CATEGORY'
export const SET_CATEGORIES = 'SET_CATEGORIES'
