{% extends "fluid.html" %}

{% load i18n lib_tags static %}
{% load render_bundle from webpack_loader %}

{% block pagetitle %}{% trans "Contacts" %}{% endblock %}

{% block extra_css %}
  {% if not debug %}
    {% render_bundle 'app' 'css' 'CONTACTS' %}
  {% endif %}
{% endblock %}

{% block extra_js %}
  {% if sync_enabled %}
  <script>
  window.userProfile = {
      abookSynced: {% if abook_synced %}true{% else %}false{% endif %}
  };
  </script>
  {% endif %}
  {% if not debug %}
    {% render_bundle 'manifest' 'js' 'CONTACTS' %}
    {% render_bundle 'vendor' 'js' 'CONTACTS' %}
    {% render_bundle 'app' 'js' 'CONTACTS' %}
  {% else %}
    {% render_bundle 'app' 'js' 'CONTACTS' %}
  {% endif %}
{% endblock %}

{% block container_content %}

  <div id="app">
  </div>

{% endblock %}
