# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-01-24 23:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('modoboa_contacts', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailaddress',
            name='type',
            field=models.CharField(choices=[('home', 'Home'), ('work', 'Work'), ('other', 'Other')], max_length=20),
        ),
        migrations.AlterField(
            model_name='phonenumber',
            name='type',
            field=models.CharField(choices=[('home', 'Home'), ('work', 'Work'), ('other', 'Other'), ('main', 'Main'), ('cellular', 'Cellular'), ('fax', 'Fax'), ('pager', 'Pager')], max_length=20),
        ),
    ]
